@@ -86,7 +86,7 @@
 #define KCALENDARCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCALENDARCORE_NO_DEPRECATED
-#  define KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56000
+#  define KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56400
 #endif
 #ifdef KCALENDARCORE_NO_DEPRECATED_WARNINGS
 #  define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0x56000
+#    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0x56400
 #  endif
 #endif
 
@@ -139,6 +139,12 @@
 #else
 #  define KCALENDARCORE_DEPRECATED_VERSION_5_96(text)
 #endif
+
+#if KCALENDARCORE_DEPRECATED_WARNINGS_SINCE >= 0x56100
+#  define KCALENDARCORE_DEPRECATED_VERSION_5_97(text) KCALENDARCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCALENDARCORE_DEPRECATED_VERSION_5_97(text)
+#endif
 #define KCALENDARCORE_DEPRECATED_VERSION_5(minor, text)      KCALENDARCORE_DEPRECATED_VERSION_5_##minor(text)
 #define KCALENDARCORE_DEPRECATED_VERSION(major, minor, text) KCALENDARCORE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KCALENDARCORE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCALENDARCORE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
@@ -204,7 +210,7 @@
 #define KCALENDARCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCALENDARCORE_NO_DEPRECATED
-#  define KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56000
+#  define KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56400
 #endif
 #ifdef KCALENDARCORE_NO_DEPRECATED_WARNINGS
 #  define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -214,7 +220,7 @@
 #  ifdef KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE KCALENDARCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0x56000
+#    define KCALENDARCORE_DEPRECATED_WARNINGS_SINCE 0x56400
 #  endif
 #endif
 
@@ -257,6 +263,12 @@
 #else
 #  define KCALENDARCORE_DEPRECATED_VERSION_5_96(text)
 #endif
+
+#if KCALENDARCORE_DEPRECATED_WARNINGS_SINCE >= 0x56100
+#  define KCALENDARCORE_DEPRECATED_VERSION_5_97(text) KCALENDARCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KCALENDARCORE_DEPRECATED_VERSION_5_97(text)
+#endif
 #define KCALENDARCORE_DEPRECATED_VERSION_5(minor, text)      KCALENDARCORE_DEPRECATED_VERSION_5_##minor(text)
 #define KCALENDARCORE_DEPRECATED_VERSION(major, minor, text) KCALENDARCORE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KCALENDARCORE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCALENDARCORE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
